from setuptools import setup
from setuptools import find_packages


VERSION = '0.1.7'

with open('README.md') as f:
    LONG_DESCRIPTION = f.read()

setup(
    name='wslarkbot',  # package name
    version=VERSION,  # package version
    description='lark(feishu) websocket client',  # package description
    long_description=LONG_DESCRIPTION,
    long_description_content_type='text/markdown',
    project_urls={
        "Documentation": "https://www.connectai-e.com",
        "Code": "http://github.com/connectAI-E/Feishu-Webhook-Proxy",
        "Issue tracker": "http://github.com/connectAI-E/Feishu-Webhook-Proxy/issues",
    },
    author="lloydzhou@gmail..com",
    license="BSD",
    keywords=["Feishu", "Lark", "Webhook", "Websocket", "Bot"],
    packages=find_packages(),
    zip_safe=False,
    install_requires=[
        "websocket",
        "pycrypto",
        "httpx"
    ]
)



import json
from typing import Dict


# 以下为飞书消息
class FeishuMessageHr(Dict):

    def __init__(self):
        super().__init__(tag='hr')


class FeishuMessageText(Dict):

    def __init__(self, text=''):
        super().__init__(text=text)


class FeishuMessageDiv(Dict):

    def __init__(self, content='', tag='plain_text', **kwargs):
        super().__init__(tag='div', text=dict(
            tag=tag,
            content=content,
        ), **kwargs)


# https://open.feishu.cn/document/common-capabilities/message-card/add-card-interaction/interactive-components/button
class FeishuMessageButton(Dict):

    def __init__(self, content='', tag='plain_text', value=dict(), type='default', **kwargs):
        super().__init__(
            tag='button',
            text=dict(tag=tag, content=content),
            value=value,
            type=type,
            **kwargs
        )


class FeishuMessageAction(Dict):

    def __init__(self, *actions, layout="flow"):
        super().__init__(tag="action", layout=layout, actions=actions)


class FeishuMessageOption(Dict):

    def __init__(self, value='', content='', tag='plain_text'):
        super().__init__(value=value, text=dict(tag=tag, content=content or value))


class FeishuMessageSelect(Dict):

    def __init__(self, *options, placeholder='', tag='plain_text', **kwargs):
        super().__init__(
            tag='select_static',
            placeholder=dict(tag=tag, content=placeholder),
            options=options,
            **kwargs,
        )


class FeishuMessageOverflow(Dict):

    def __init__(self, *options, placeholder='', tag='plain_text', **kwargs):
        super().__init__(
            tag='overflow',
            placeholder=dict(tag=tag, content=placeholder),
            options=options,
            **kwargs,
        )


class FeishuMessageSelectPerson(Dict):

    def __init__(self, *persons, placeholder='', tag='plain_text', **kwargs):
        super().__init__(
            tag='select_person',
            placeholder=dict(tag=tag, content=placeholder),
            options=[{'value': v} if isinstance(v, str) else v for v in persons],
            **kwargs,
        )


class FeishuMessageDatePicker(Dict):
    def __init__(self, content='Please select date', tag='plain_text'):
        super().__init__(tag='date_picker', placeholder=dict(tag=tag, content=content))


class FeishuMessageCardConfig(Dict):
    def __init__(self, update_multi=True, enable_forward=True):
        super().__init__(update_multi=update_multi, enable_forward=enable_forward)


class FeishuMessageCardHeader(Dict):
    def __init__(self, content='', tag='plain_text', template='default'):
        super().__init__(title=dict(tag=tag, content=content), template=template)


class FeishuMessageCard(Dict):

    def __init__(self, *elements, header=None, config=None):
        if isinstance(header, str):
            header = FeishuMessageCardHeader(header)
        elif not header:
            header = FeishuMessageCardHeader()

        if not config:
            config = FeishuMessageCardConfig()

        super().__init__(header=header, elements=elements, config=config)


class FeishuMessagePlainText(Dict):
    def __init__(self, content=''):
        super().__init__(tag='plain_text', content=content)


class FeishuMessageMDText(Dict):
    def __init__(self, content=''):
        super().__init__(tag='lark_md', content=content)


class FeishuMessageLarkMD(Dict):
    def __init__(self, content='', is_short=False):
        super().__init__(is_short=is_short, text=dict(
            tag='lark_md', content=content,
        ))


class FeishuMessageImage(Dict):
    def __init__(self, img_key='', alt='', tag='', mode='fit_horizontal', preview=True):
        super().__init__(
            tag='img',
            img_key=img_key,
            alt=dict(tag=tag, content=alt),
            mode=mode,
            preview=preview,
        )


class FeishuMessageMarkdown(Dict):
    def __init__(self, content=''):
        super().__init__(tag='markdown', content=content)


class FeishuMessageNote(Dict):
    def __init__(self, *elements):
        super().__init__(tag='note', elements=elements)


class FeishuMessageConfirm(Dict):
    def __init__(self, title='', text=''):
        super().__init__(
            title=dict(tag='plain_text', content=title),
            text=dict(tag='plain_text', content=text),
        )




import click
from .client import *
from .message import *


@click.command()
@click.option('--app_id', prompt="APP ID", help='Your app_id')
@click.option('--app_secret', default='', prompt="APP SECRET", help='Your app_secret')
@click.option('--verification_token', default='',
              prompt="VERIFICATION TOKEN", help='Your verification_token')
@click.option('--encrypt_key', prompt="ENCRYPT KEY", help='Your encrypt_key')
@click.option('--debug', default=False, prompt="DEBUG MODE", help='debug mode')
def main(app_id, app_secret, verification_token, encrypt_key, debug):
    class MyBot(Bot):
        def on_message(self, data, *args, **kwargs):
            print('on_message', self.app_id, data)
            if 'header' in data:
                if data['header']['event_type'] == 'im.message.receive_v1' and data['event']['message']['message_type'] == 'text':
                    message_id = data['event']['message']['message_id']
                    content = json.loads(data['event']['message']['content'])
                    text = content['text']
                    # 测试回复消息，初始化bot的时候，需要配置app_secret才能发出去消息
                    self.reply_text(message_id, 'reply: ' + text)

    bot = MyBot(
        app_id,
        app_secret=app_secret,
        encrypt_key=encrypt_key,
        verification_token=verification_token
    )
    client = Client(bot)
    client.start(debug)


if __name__ == "__main__":
    main()

